Detailed Module Documentation
=============================

This section contains the complete auto-generated API documentation for all modules, organized into two main categories:

.. toctree::
   :maxdepth: 2

   base_classes
   kicad_classes